@@ -1,9 +1,13 @@
 package MojoX::Encode::Gzip;
+
+# ABSTRACT: Gzip a Mojo::Message::Response
+
 use strict;
 use warnings;
+
 use base 'Mojo::Base';
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use Compress::Zlib ();
 
@@ -37,8 +41,8 @@ sub maybe_gzip {
         return undef;
     }
 
-   eval { local $/; $body = <$body> } if ref $body;
-   die "Response body is an unsupported kind of reference" if ref $body;
+    eval { local $/; $body = <$body> } if ref $body;
+    die "Response body is an unsupported kind of reference" if ref $body;
 
     $res->body( Compress::Zlib::memGzip( $body ) );
     $res->headers->content_length( $length );
@@ -50,12 +54,18 @@ sub maybe_gzip {
 
 1;
 
-__END__
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 MojoX::Encode::Gzip - Gzip a Mojo::Message::Response
 
+=head1 VERSION
+
+version 1.11
+
 =head1 SYNOPSIS
 
     use MojoX:Encode::Gzip;
@@ -70,7 +80,6 @@ MojoX::Encode::Gzip - Gzip a Mojo::Message::Response
     );
     $success = $gzip->maybe_gzip($tx);
 
-
 =head1 DESCRIPTION
 
 Gzip compress a Mojo::Message::Response if client supports it.
@@ -111,16 +120,12 @@ Please report any bugs or feature requests to C<bug-mojox-encode-gzip at rt.cpan
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MojoX-Encode-Gzip>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc MojoX::Encode::Gzip
 
-
 You can also look for information at:
 
 =over 4
@@ -154,6 +159,20 @@ Copyright 2008 Mark Stosberg, all rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Renee Baecker <reneeb@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Renee Baecker.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+__END__
+
+
 1; # End of MojoX::Encode::Gzip
